@@ -7,15 +7,33 @@ from unittest import mock
 
 import pysolr
 import ckan.tests.helpers as helpers
-import ckanext.resource_indexer.utils as utils
+from ckan.lib.search import rebuild
+
+from ckanext.resource_indexer import config
+
 
 @pytest.mark.usefixtures("with_plugins", "clean_db", "clean_index")
 @pytest.mark.ckan_config(
     "ckan.plugins", "resource_indexer plain_resource_indexer"
 )
 class TestPlainIndexer(object):
+    @mock.patch("ckanext.resource_indexer.utils.select_indexable_resources")
+    def test_bypassing_indexation(self, selector, monkeypatch, package):
+        assert selector.call_count == 0
+
+        rebuild(package["id"])
+        assert selector.call_count == 1
+
+        monkeypatch.setenv("CKANEXT_RESOURCE_INDEXER_BYPASS", "1")
+        rebuild(package["id"])
+        assert selector.call_count == 1
+
+        monkeypatch.setenv("CKANEXT_RESOURCE_INDEXER_BYPASS", "")
+        rebuild(package["id"])
+        assert selector.call_count == 2
+
     def test_resource_is_not_indexed_without_explicit_config_options(
-            self, create_with_upload, package
+        self, create_with_upload, package
     ):
         """By default, no files are indexed.
 
@@ -31,7 +49,9 @@ class TestPlainIndexer(object):
     @pytest.mark.ckan_config(
         "ckanext.resource_indexer.indexable_formats", "txt json"
     )
-    def test_resource_is_indexed_when_format_enabled(self, create_with_upload, package):
+    def test_resource_is_indexed_when_format_enabled(
+        self, create_with_upload, package
+    ):
         """Resources with supported formats are indexed.
 
         Multiple resources can be indexed as a part of the single
@@ -96,7 +116,7 @@ class TestBoost:
         helpers.call_action("package_search", q="hello")
         assert fn.call_args.kwargs["qf"] == QUERY_FIELDS
 
-    @pytest.mark.ckan_config(utils.CONFIG_INDEX_FIELD, "custom_field")
+    @pytest.mark.ckan_config(config.CONFIG_INDEX_FIELD, "custom_field")
     def test_custom_index_field_without_explicit_boost_ignored(
         self, monkeypatch
     ):
@@ -105,8 +125,8 @@ class TestBoost:
         helpers.call_action("package_search", q="hello")
         assert fn.call_args.kwargs["qf"] == QUERY_FIELDS
 
-    @pytest.mark.ckan_config(utils.CONFIG_INDEX_FIELD, "custom_field")
-    @pytest.mark.ckan_config(utils.CONFIG_BOOST, 2)
+    @pytest.mark.ckan_config(config.CONFIG_INDEX_FIELD, "custom_field")
+    @pytest.mark.ckan_config(config.CONFIG_BOOST, 2)
     def test_boosted_field(self, monkeypatch):
         fn = mock.MagicMock()
         monkeypatch.setattr(pysolr.Solr, "search", fn)
