@@ -6,6 +6,8 @@ import tempfile
 import enum
 import json
 from typing import Any, Iterable, Optional
+from contextvars import ContextVar
+from contextlib import contextmanager
 
 import requests
 
@@ -17,6 +19,8 @@ from . import config
 
 log = logging.getLogger(__name__)
 
+bypass_flag = ContextVar("bypass_flag", default=False)
+
 
 class Weight(enum.IntEnum):
     skip = 0
@@ -226,6 +230,7 @@ def merge_text_chunks(pkg_dict, chunks):
 
 def extract_pdf(path) -> Iterable[str]:
     import pdftotext
+    processor = config.pdf_processor()
 
     try:
         with open(path, "rb") as file:
@@ -238,7 +243,8 @@ def extract_pdf(path) -> Iterable[str]:
         pdf_content = []
     for page in pdf_content:
         # normalize null-terminated strings that appear in old versions of poppler
-        yield page.rstrip("\x00")
+        content = page.rstrip("\x00")
+        yield processor(content)
 
 
 def extract_plain(path) -> Iterable[str]:
@@ -279,4 +285,16 @@ def bypass_indexation() -> bool:
 
     May be used for fast index re-builds.
     """
-    return bool(os.getenv("CKANEXT_RESOURCE_INDEXER_BYPASS"))
+    return bool(os.getenv("CKANEXT_RESOURCE_INDEXER_BYPASS")) or bypass_flag.get()
+
+
+
+@contextmanager
+def disabled_indexation():
+    """With-context that disables indexation of the resource.
+    """
+    token = bypass_flag.set(True)
+    try:
+        yield
+    finally:
+        bypass_flag.reset(token)
